<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       www.teowin.nl
 * @since      1.0.0
 *
 * @package    Pw
 * @subpackage Pw/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Pw
 * @subpackage Pw/public
 * @author     Teowin <plugins@teowin.nl>
 */

defined( 'ABSPATH' ) || exit;

class Pw_Public {

	public $ids = array();
    public $discountlist = array();

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pw_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pw_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/pw-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pw_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pw_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/pw-public.js', array( 'jquery' ), $this->version, false );

	}

	public function powerall_save_user_fields( $user_id ) {


		/*	if ( !current_user_can( 'edit_user', $user_id ) ) {
				return false;
			}
		*/
			update_user_meta( $user_id, 'address', $_POST['address'] );
			update_user_meta( $user_id, 'city', $_POST['city'] );
			update_user_meta( $user_id, 'postalcode', $_POST['postalcode'] );
			update_user_meta( $user_id, 'my_field', $_POST['my_field'] );


		//  $user = get_user_by_email();

	}

	/*
	*  Calls powerall customer prices with array of product codes (SKU) fields on product category page in the shop
	*/

    public function get_customer_prices(){
	    if (is_user_logged_in()) {
		    global $wp_query;

		    if ( ! $wp_query->is_post_type_archive() ) {
			    return;
		    }

		    $ids = wp_list_pluck( $wp_query->posts, "_sku" );
		    $_SESSSION['twerror'] = 0;

		    $paged_current_page      = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		    $_SESSION['twdata_page'] = $paged_current_page;

		    $klantnummer = null;


		    $klantnummer = get_user_meta( get_current_user_id(), 'powerall_id', true );


		    if ( $klantnummer ) {

			 //   print_r( $ids );

			    $str = implode( ",", $ids );

			    $dropship  = PwDropShipment::get_instance();
			    $pricedata = $dropship->powerall_get_customer_prices( $klantnummer, $str );
			    if ( $pricedata ) {
				    $_SESSION['twdata'] = $pricedata;
			    } else {
				    $_SESSION['twdata'] = null;
				    $_SESSION['twerror'] = 1;
			    }
		    }

	    } else
	    {
		    $_SESSION['twdata'] = null;
		    $_SESSION['twerror'] = 0;
	    }


    }

     public function set_price($post){
        global $product;
	     if (is_user_logged_in()) {
		     $koekie = null;

		     if ($_SESSION['twerror'] == 0) {
			     if ( isset( $_SESSION['twdata'] ) ) {
				     $koekie = $_SESSION['twdata'];
			     }
		     }
			
			 if ($koekie) {
		       $key = array_search($product->get_sku(), array_column($koekie , 'ProductCode'));
		       echo $product->get_id() . ' ' . $this->discountlist[ $key ];
			 }
	     }
     }

    public function read_prices() {
	    if ( is_user_logged_in() ) {


		    if ( isset( $_SESSION['twdata'] ) ) {
			    $koekie = $_SESSION['twdata'];
		    } else {
			    $koekie = null;
		    }
		    global $user_id;
		    if ( ! $koekie ) {
			    if ( is_user_logged_in() ) {
				    $this->get_customer_prices();

				    //  $price_html = '<p style="color: red;">Korting niet gevonden, druk F5 om de pagina te verversen</p>';
				    if ( isset( $_SESSION['twdata'] ) ) {
					    $koekie = $_SESSION['twdata'];
				    } else {
					    $koekie = null;
				    }
			    }
		    }
	    }

    }

	public function alter_price_display( $price_html, $product ) {

		if (is_user_logged_in()) {
			// ONLY ON FRONTEND
			if ( is_admin() ) {
				return $price_html;
			}

			// ONLY IF PRICE NOT NULL
			//	if ( '' === $product->get_price() ) return $price_html;

			// IF CUSTOMER LOGGED IN, APPLY 20% DISCOUNT
			//	if ( wc_current_user_has_role( 'customer' ) ) {


			if ( isset( $_SESSION['twdata'] ) ) {
				$koekie = $_SESSION['twdata'];
			} else {
				$koekie = null;
			}


			if ( ! $koekie ) {
				if ( is_user_logged_in() ) {
					$this->get_customer_prices();

					//  $price_html = '<p style="color: red;">Korting niet gevonden, druk F5 om de pagina te verversen</p>';
					if ( isset( $_SESSION['twdata'] ) ) {
						$koekie = $_SESSION['twdata'];
					} else {
						$koekie = null;
					}
				}

			}

			if ( $koekie ) {

				$key            = array_search( $product->get_sku(), array_column( $koekie, 'ProductCode' ) );
				$orig_price     = $koekie[ $key ]['SalesPrice'];
				$discount_price = $koekie[ $key ]['CustomerPrice'];

				//   if (!is_cart()) {
				//   $orig_price = wc_get_price_to_display( $product );
				$price_html = '<span>(Bruto: ' . wc_price( $orig_price ) . ')</br> <b> ' . wc_price( $discount_price ) . '</b></span>';

				//  }
				//  else {
				//      $price_html .= $price_html . ' <b>' . wc_price( $discount_price ) . '</b>
				//  }

			} else {
				$price_html = '<span><b> ' . wc_price( $product->get_price()) . '</b></br><p>Kortingafspraak? </br>Bel of mail ons</p></span>';
			}
		} else {
		    // niet ingelogd.
            $price_html = '<span><b> ' . wc_price( $product->get_price()) . '</b></br><p>Kortingafspraak? </br>Login om kortingen te zien</p></span>';
        }
		return $price_html;

	}

	/**
	 * Display discount price on cart price column
	 *
	 * @since    1.0.0
	 */
	public function display_discount_on_cart_price_column( $price, $values, $cart_item_key ) {

			$slashed_price = $values['data']->get_price_html();

			$is_on_sale = true ; //$values['data']->is_on_sale();

			if ( $is_on_sale ) {

				$price = $slashed_price;
			}


		return $price;

	}

	public function hack_the_table($cart_item, $cart_item_key){
		echo '<td>see it work.</td>';

	}

	public function before_calculate_totals( $_cart ){
		// loop through the cart_contents
		if (isset($_SESSION['twdata'])) {
	      $koekie = $_SESSION['twdata'];
		} else {
		  $koekie = null;
		}

		if (!$koekie){
			if (is_user_logged_in()) {
				$this->get_customer_prices();

			//	$price_html = '<p style="color: red;">Korting niet gevonden, druk F5 om de pagina te verversen</p>';
			}
			if (isset($_SESSION['twdata'])) {
			  $koekie = $_SESSION['twdata'];
			} else {
			  $koekie = null;
			}
		}

		foreach ( $_cart->cart_contents as $cart_item_key => &$item ) {


			// you will need to determine the product id you want to modify, only when the "donation_amount" is passed
		//	$product = wc_get_product( $item->get_product_id() );
			$_woo_product = wc_get_product( $item['product_id'] );
			if (isset($koekie)) {
				$key = array_search( $_woo_product->get_sku(), array_column( $koekie, 'ProductCode' ) );

				//    $test = $_woo_product->get_regular_price();
				$orig_price     = $koekie[ $key ]['SalesPrice'];
				$discount_price = $koekie[ $key ]['CustomerPrice'];

				if ( $orig_price ) {

					// save to the cart data
					//	$item['data']->price = $discount_price;
					// new versions of WooCommerce may require (instead of line above)...
					update_post_meta( $_woo_product->get_id(), '_regular_price', $orig_price );
					$item['data']->set_price( $discount_price );
				}
			}

		}
	}


	/*
	 *  WooCommerce my_account/orders page.
	 */
    public function get_orders_for_account_page($customerId){
        
	    if (is_user_logged_in()) {
		    global $wp_query;
		    
	
		    if ( !is_account_page() ) {
			    return;
		    }
		    
		    if (! is_wc_endpoint_url( 'orders' )) return;

		    $paged_current_page      = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		    $_SESSION['twdata_page'] = $paged_current_page;
		    
		    if ($paged_current_page > 1) return;

		    $klantnummer = null;

		    $klantnummer = get_user_meta( get_current_user_id(), 'powerall_id', true );
		    
		    if ( $klantnummer ) {
		        $customer = new WC_Customer(get_current_user_id());
		        $billing_adress   = $customer->get_billing('view');
		        $shipment_address = $customer->get_shipping('view');
		        
			    $dropship  = PwDropShipment::get_instance();
			    $pworders = $dropship->powerall_get_customer_orders( $klantnummer);

			    if ($pworders && $pworders['TotalItems'] > 0) {


				    foreach ( $pworders['Items'] as $pworder ) {

				        $wooOrder = wc_get_orders(array(
				            'limit'        => 1, 
				            'orderby'      => 'date',
				            'order'        => 'DESC',
				            'meta_key'     => '_powerallOrderID', 
				            'meta_compare' => 'EQUALS', 
				            'meta_value'   => $pworder['Id']
				        ));
					  
				      $pwFout = 0;
					      
                      if (!$wooOrder){
                          $args = array(                           
                              'customer_id'   => get_current_user_id(),
                              'created_via'   => 'PowerAll Offline',
                              );
                          
                           // Get an instance of the current WC_DateTime object
                            $date_time = new WC_DateTime();
                            $date_time->createFromFormat('Y-m-d H:i:s', $pworder['OrderDate']);
                            
                            $wooOrder = wc_create_order($args);
                            $wooOrder->set_address($billing_adress, 'billing');
                            $wooOrder->set_address($shipment_address, 'shipping');
                            $wooOrder->set_date_created($date_time);
                            $wooOrder->set_prices_include_tax( 'yes' === get_option( 'woocommerce_prices_include_tax' ));
                            
                            $products = $pworder['Lines'];
                            
                            foreach ($products as $pwProduct) {
                                $wooProduct = wc_get_product(wc_get_product_id_by_sku($pwProduct['ProductCode']));
                                if ($wooProduct){
                                   $wooOrder->add_product($wooProduct, $pwProduct['Quantity'], array('total' => $pwProduct['NetPrice']) ); 
                                } else {
                                    $pwFout = 1;
                                }
                            }
                          
                           $wooOrder->calculate_totals(true);
                           $wooOrder->update_meta_data('_powerallOrderID', $pworder['Id']);
                          // $wooOrder->update_status('Afgerond', 'PowerAll Winkelorder');
                           $wooOrder->update_status('completed');
                           $wooOrder->save();
                      }
				    }
				   
			    }
			    else {
			        $message = '<div style="border: 1px solid black; background-color: orange;">Bijwerken van orders uit Powerall is niet gelukt!</br>Probeer de pagina te verversen of neem contact op met de webshop eigenaar.</div>';
			        wc_print_notice( $message, 'notice' );
			    }
			    $wp_query->reset_postdata();
			    return true;
		  }
	    }
	   return true;
    }


	public function add_powerall_info_to_edit_account_form() {
		$user = wp_get_current_user();

		$paymentTerms = get_user_meta($user->ID, 'paycondition', true);
		if ( (int) ($paymentTerms < 50 || $paymentTerms > 60) ){
			$paymentTerms = _( 'Online betalen/Contant', 'twpw' );
		}

		$customerID   = get_user_meta($user->ID, 'powerall_id', true);
		// First Field
		?>
		<p class="woocommerce-form-row woocommerce-form-row--first form-row form-row-first">
			<label for="paymentTerms"><?php _e( 'Powerall Betaaltermijn', 'twpw' ); ?>
				<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="paymentTerms" id="paymentTerms" value="<?php echo esc_attr( $paymentTerms ) ; ?> " readonly />
		</p>
		<?php
		// Second Field
		?>
		<p class="woocommerce-form-row woocommerce-form-row--last form-row form-row-last ">
			<label for="favorite_color"><?php _e( 'Powerall klantnummer', 'twpw' ); ?>
				<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="favorite_color2" id="favorite_color2" value="<?php echo esc_attr( $customerID ); ?>" readonly />
		</p>
		<div class="clear"></div>
		<?php
	}

    public function custom_product_price_field(){

         // dit wordt al geregeld in alter_price_display().
    ?>

    		<table cellspacing="0">
			<tbody>
			<tr>
				<td >
					<label for="gift_card_amount"><?php echo __( "Amount", 'twpw' ); ?></label>
            </td>
            <td class="price">
                <?php
            //					$get_price = get_post_meta ( $product->get_id(), '_gift_card_price' );
            //					$price = 0;
            //					if ( isset( $get_price[0] ) ) {
            //						$price =  wc_price( $get_price[0] ) ;
            //					}
                            //	echo $price;

                                $koekie = 0;

                                if ( isset( $_SESSION['twdata'] ) ) {
                                  $koekie = $_SESSION['twdata'];
                                } else {
                                  $koekie = null;
                                }


                                if ( ! $koekie ) {

                                if ( is_user_logged_in() ) {
                                  $this->get_customer_prices();

                                    //  $price_html = '<p style="color: red;">Korting niet gevonden, druk F5 om de pagina te verversen</p>';
                                    if ( isset( $_SESSION['twdata'] ) ) {
                                      $koekie = $_SESSION['twdata'];
                                    } else {
                                      $koekie = null;
                                    }
                                }

                                }

                                if ( $koekie ) {

                                $key            = array_search( $product->get_sku(), array_column( $koekie, 'ProductCode' ) );
                                $orig_price     = $koekie[ $key ]['SalesPrice'];
                                $discount_price = $koekie[ $key ]['CustomerPrice'];

                                //   if (!is_cart()) {
                                //   $orig_price = wc_get_price_to_display( $product );
                                $price_html = '<span>(Bruto: ' . wc_price( $orig_price ) . ')</br> <b> ' . wc_price( $discount_price ) . '</b></span>';

                                //  }
                                //  else {
                                //      $price_html .= $price_html . ' <b>' . wc_price( $discount_price ) . '</b>
                                //  }

                                } else {
                                  $price_html = '<span>Log in voor </br>actuele prijzen</br></span>';
                                }
                                  echo $price_html
                                ?>



            </td>
            </tr>
            </tbody>
            </table>
<?php
            }

}
